summaryrefslogtreecommitdiffstats
path: root/sys/nwfs/nwfs_io.c
diff options
context:
space:
mode:
authorphk <phk@FreeBSD.org>2000-04-02 15:24:56 +0000
committerphk <phk@FreeBSD.org>2000-04-02 15:24:56 +0000
commit8ee11d587fcf66a50146b00f04bb5db7b955b795 (patch)
treec184bd0e6c7538049e6b3655c28f4556a7c1a465 /sys/nwfs/nwfs_io.c
parent090fde9a7695bc804b6a26eb67cb706fd805231a (diff)
downloadFreeBSD-src-8ee11d587fcf66a50146b00f04bb5db7b955b795.zip
FreeBSD-src-8ee11d587fcf66a50146b00f04bb5db7b955b795.tar.gz
Move B_ERROR flag to b_ioflags and call it BIO_ERROR.
(Much of this done by script) Move B_ORDERED flag to b_ioflags and call it BIO_ORDERED. Move b_pblkno and b_iodone_chain to struct bio while we transition, they will be obsoleted once bio structs chain/stack. Add bio_queue field for struct bio aware disksort. Address a lot of stylistic issues brought up by bde.
Diffstat (limited to 'sys/nwfs/nwfs_io.c')
-rw-r--r--sys/nwfs/nwfs_io.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/nwfs/nwfs_io.c b/sys/nwfs/nwfs_io.c
index 6f7a6c8..ab24a29 100644
--- a/sys/nwfs/nwfs_io.c
+++ b/sys/nwfs/nwfs_io.c
@@ -311,7 +311,7 @@ nwfs_doio(bp, cr, p)
break;
};
if (error) {
- bp->b_flags |= B_ERROR;
+ bp->b_ioflags |= BIO_ERROR;
bp->b_error = error;
}
} else { /* write */
@@ -330,7 +330,7 @@ nwfs_doio(bp, cr, p)
/*
* For an interrupted write, the buffer is still valid
* and the write hasn't been pushed to the server yet,
* so we can't set B_ERROR and report the interruption
* by setting B_EINTR. For the B_ASYNC case, B_EINTR
* is not relevant, so the rpc attempt is essentially
* a noop. For the case of a V3 write rpc not being
@@ -357,7 +357,7 @@ nwfs_doio(bp, cr, p)
splx(s);
} else {
if (error) {
- bp->b_flags |= B_ERROR;
+ bp->b_ioflags |= BIO_ERROR;
bp->b_error /*= np->n_error */= error;
/* np->n_flag |= NWRITEERR;*/
}
@@ -330,7 +330,7 @@ nwfs_doio(bp, cr, p)
* For an interrupted write, the buffer is still valid
* and the write hasn't been pushed to the server yet,
- * so we can't set B_ERROR and report the interruption
+ * so we can't set BIO_ERROR and report the interruption
* by setting B_EINTR. For the B_ASYNC case, B_EINTR
* is not relevant, so the rpc attempt is essentially
OpenPOWER on IntegriCloud